@@ -641,12 +641,12 @@ pygvfs_get_mime_type_for_data(PyObject *self, PyObject *args)
 {
     char *data;
     char const *mime;
-    int data_size, data_size1 = -G_MAXINT;
+    Py_ssize_t data_size, data_size1 = PY_SSIZE_T_MIN;
     
     if(!PyArg_ParseTuple(args, "s#|i:gnomevfs.get_mime_type_for_data",
 			 &data, &data_size, &data_size1))
 	return NULL;
-    if (data_size1 != -G_MAXINT)
+    if (data_size1 != PY_SSIZE_T_MIN)
 	PyErr_Warn(PyExc_DeprecationWarning, "ignoring deprecated argument data_size");
     pyg_begin_allow_threads;
     mime = gnome_vfs_get_mime_type_for_data(data, data_size);
@@ -1954,7 +1954,7 @@ _wrap_gnome_vfs_dns_sd_resolve_sync(PyObject *self, PyObject *args, PyObject *kw
     py_hash = PyDict_New();
     g_hash_table_foreach(hash, (GHFunc) __text_hash_to_dict, py_hash);
     g_hash_table_destroy(hash);
-    retval = Py_BuildValue("Ns#", py_hash, text_raw, text_raw_len);
+    retval = Py_BuildValue("Ns#", py_hash, text_raw, (Py_ssize_t) text_raw_len);
     g_free(text_raw);
     return retval;
 }
